Zdog Backend
============

.. automodule:: plato.draw.zdog

.. autoclass:: Scene
   :members:

2D Graphics Primitives
----------------------

.. autoclass:: Arrows2D
   :members:

.. autoclass:: Disks
   :members:

.. autoclass:: Polygons
   :members:

.. autoclass:: Spheropolygons
   :members:

3D Graphics Primitives
----------------------

.. autoclass:: Box
   :members:

.. autoclass:: ConvexPolyhedra
   :members:

.. autoclass:: ConvexSpheropolyhedra
   :members:

.. autoclass:: Lines
   :members:

.. autoclass:: Spheres
   :members:
